@@ -6,7 +6,7 @@ use strict qw(subs vars refs);				# Make sure we can't mess up
 use warnings FATAL => 'all';				# Enable warnings to catch errors
 
 # Initialize our version
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 # Use Error.pm's try/catch semantics
 use Error qw( :try );
@@ -32,6 +32,10 @@ $|++;
 # Sysread error hits
 my $sysreaderr = 0;
 
+# Set the binmode stuff
+binmode( STDIN );
+binmode( STDOUT );
+
 # This is the subroutine that will get executed upon the fork() call by our parent
 sub main {
 	# Okay, now we listen for commands from our parent :)
@@ -539,14 +543,6 @@ Nothing.
 
 L<POE::Component::SimpleDBI>
 
-L<DBI>
-
-L<POE>
-L<POE::Wheel::Run>
-
-L<POE::Component::DBIAgent>
-L<POE::Component::LaDBI>
-
 =head1 AUTHOR
 
 Apocalypse E<lt>apocal@cpan.orgE<gt>
